@@ -8,8 +8,8 @@ require Exporter;
 @RRD::Query::ISA = qw(Exporter);
 @RRD::Query::EXPORT_OK = qw(isNaN);
 
-# $Id: Query.pm,v 1.12 2005/02/04 16:58:53 rs Exp $
-$RRD::Query::VERSION = sprintf "%d.%03d", q$Revision: 1.12 $ =~ /(\d+)/g;
+# $Id: Query.pm,v 1.15 2005/02/28 17:37:12 rs Exp $
+$RRD::Query::VERSION = sprintf "%d.%03d", q$Revision: 1.15 $ =~ /(\d+)/g;
 
 =pod
 
@@ -110,6 +110,8 @@ consolidation function is used.
 
 Time offset to go back in the past from the last inserted value time.
 
+=back
+
 =head3 Throws
 
 =over 4
@@ -149,7 +151,7 @@ sub fetch
             if(exists($ds{$item}))
             {
                 # substitute variables by their value
-                $item = $self->fetch($item, 1);
+                $item = $self->fetch($item, %args);
                 if(isNaN($item))
                 {
                     $item = 'NaN';
@@ -185,7 +187,7 @@ sub fetch
         if($names->[$i] eq $ds)
         {
             $found = 1;
-            $value = $data->[0]->[$i];
+            $value = $data->[-1]->[$i];
             last;
         }
     }
